@@ -56,10 +56,7 @@
 #![allow(clippy::wildcard_imports)] // breaks code, false positives
 #![allow(clippy::option_if_let_else)] // too pedantic, not that useful...
 #![allow(clippy::upper_case_acronyms)] // questionable
-#![allow(clippy::needless_for_each)]
-// I like my iterators :(
-// temporary disable because of false positive: https://github.com/rust-lang/rust-clippy/issues/7859
-#![allow(clippy::question_mark)]
+#![allow(clippy::needless_for_each)] // I like my iterators :(
 
 // for the "ci-autoclean" feature, we don't need all these modules so ignore them
 cfg_if::cfg_if! {
@@ -77,6 +74,7 @@ cfg_if::cfg_if! {
         mod top_items_summary;
         mod date;
         mod clean_unref;
+        mod verify;
 
         // use
         use crate::cache::caches::{Cache, RegistrySuperCache};
@@ -91,6 +89,7 @@ cfg_if::cfg_if! {
         use crate::top_items_summary::*;
         use crate::clean_unref::*;
         use crate::cli::{CargoCacheCommands};
+        //use crate::verify;
     }
 }
 
@@ -113,7 +112,7 @@ fn main() {
     let config_enum = cli::clap_to_enum(config);
 
     // handle hidden "version" subcommand
-    if config.is_present("version") {
+    if config.is_present("version") || matches!(config_enum, CargoCacheCommands::Version) {
         println!("cargo-cache {}", cli::get_version());
         process::exit(0);
     }
@@ -470,6 +469,36 @@ fn main() {
                 eprintln!("Warning: there is nothing to be dry run!");
             }
         }
+        CargoCacheCommands::Verify {
+            clean_corrupted,
+            dry_run,
+        } => {
+            println!("Verifying cache, this may take some time...\n");
+            if let Err(failed_verifications) = verify::verify_crates(&mut registry_sources_caches) {
+                eprintln!("\n");
+                failed_verifications
+                    .iter()
+                    .for_each(|diff| println!("{}", diff.details()));
+                eprintln!(
+                    "\nFound {} possible corrupted sources.",
+                    failed_verifications.len()
+                );
+
+                if clean_corrupted {
+                    verify::clean_corrupted(
+                        &mut registry_sources_caches,
+                        &failed_verifications,
+                        dry_run,
+                    );
+                } else {
+                    println!("Hint: use `cargo cache verify --clean-corrupted` to remove them.");
+                }
+
+                std::process::exit(1)
+            } else {
+                std::process::exit(0);
+            }
+        }
         _ => (),
     }
 
